/*
  Darkly Pygments Theme
  (c) 2014 Sourcey
  http://sourcey.com
*/

pre {
  white-space: pre;
  overflow: auto;
  word-wrap: normal; /* horizontal scrolling */
  -moz-border-radius: 3px;
  -webkit-border-radius: 3px;
  border-radius: 3px;
  padding: 20px;
  background: #343642;
  color: #C1C2C3;
}

.hll { background-color: #ffc; }
.gd { color: #2e3436; background-color: #0e1416; }
.gr { color: #eeeeec; background-color: #c00; }
.gi { color: #babdb6; background-color: #1f2b2d; }
.go { color: #2c3032; background-color: #2c3032; }
.kt { color: #e3e7df; }
.ni { color: #888a85; }
.c,.cm,.c1,.cs { color: #8D9684; }
.err,.g,.l,.n,.x,.p,.ge,
.gp,.gs,.gt,.ld,.s,.nc,.nd,
.ne,.nl,.nn,.nx,.py,.ow,.w,.sb,
.sc,.sd,.s2,.se,.sh,.si,.sx,.sr,
.s1,.ss,.bp { color: #C1C2C3; }
.k,.kc,.kd,.kn,.kp,.kr,
.nt { color: #729fcf; }
.cp,.gh,.gu,.na,.nf { color: #E9A94B ; }
.m,.nb,.no,.mf,.mh,.mi,.mo,
.il { color: #8ae234; }
.o { color: #989DAA; }
.nv,.vc,.vg,.vi { color: #fff; }
