<!DOCTYPE html>
<!--[if IE 8 ]><html class="ie ie8" lang="{{ DEFAULT_LANG }}"> <![endif]-->
<!--[if (gte IE 9)|!(IE)]><!-->
<html lang="{{ DEFAULT_LANG }}">
<!--<![endif]-->
	<head>
    {% block head %}
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
        <meta name="author" content="{{ AUTHOR }}">

        {% if GOOGLE_SITE_VERIFICATION %}
            <meta name="google-site-verification" content="{{ GOOGLE_SITE_VERIFICATION }}">
        {% endif %}

        <title>{{ SITENAME }}{% block title %}{% if SITESUBTITLE and SHOW_SITESUBTITLE_IN_HTML %} - {{ SITESUBTITLE }}{% endif %}{% endblock title %}</title>

        {% if FEED_ALL_ATOM %}
            <link href="{{ FEED_DOMAIN }}/{{ FEED_ALL_ATOM }}" type="application/atom+xml" rel="alternate" title="{{ SITENAME }} Full Atom Feed" />
        {% endif %}
        {% if FEED_ALL_RSS %}
            <link href="{{ FEED_DOMAIN }}/{{ FEED_ALL_RSS }}" type="application/rss+xml" rel="alternate" title="{{ SITENAME }} Full RSS Feed" />
        {% endif %}
        {% if FEED_ATOM %}
            <link href="{{ FEED_DOMAIN }}/{{ FEED_ATOM }}" type="application/atom+xml" rel="alternate" title="{{ SITENAME }} Atom Feed" />
        {% endif %}
        {% if FEED_RSS %}
            <link href="{{ FEED_DOMAIN }}/{{ FEED_RSS }}" type="application/rss+xml" rel="alternate" title="{{ SITENAME }} RSS Feed" />
        {% endif %}
        {% if CATEGORY_FEED_ATOM and category %}
            <link href="{{ FEED_DOMAIN }}/{{ CATEGORY_FEED_ATOM.format(slug=category.slug) }}" type="application/atom+xml" rel="alternate" title="{{ SITENAME }} Categories Atom Feed" />
        {% endif %}
        {% if CATEGORY_FEED_RSS and category %}
            <link href="{{ FEED_DOMAIN }}/{{ CATEGORY_FEED_RSS.format(slug=category.slug) }}" type="application/rss+xml" rel="alternate" title="{{ SITENAME }} Categories RSS Feed" />
        {% endif %}
        {% if TAG_FEED_ATOM and tag %}
            <link href="{{ FEED_DOMAIN }}/{{ TAG_FEED_ATOM.format(slug=tag.slug) }}" type="application/atom+xml" rel="alternate" title="{{ SITENAME }} Tags Atom Feed" />
        {% endif %}
        {% if TAG_FEED_RSS and tag %}
            <link href="{{ FEED_DOMAIN }}/{{ TAG_FEED_RSS.format(slug=tag.slug) }}" type="application/rss+xml" rel="alternate" title="{{ SITENAME }} Tags RSS Feed" />
        {% endif %}

        <!-- CSS -->
        <link rel="stylesheet" href="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/css/style.css?v=1.0.1">

        <!-- Custom CSS -->
        {% if THEME_COLOR %}
        	<link rel="stylesheet" href="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/css/colors/{{ THEME_COLOR }}.css" id="colors">
        {% else %}
        	<link rel="stylesheet" href="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/css/colors/blue.css" id="colors">
        {% endif %}

        <!-- Code highlight color scheme -->
        {% if COLOR_SCHEME_CSS %}
            <link href="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/css/code_blocks/{{ COLOR_SCHEME_CSS }}" rel="stylesheet">
        {% else %}
            <link href="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/css/code_blocks/github-light.css" rel="stylesheet">
        {% endif %}

        {% if CSS_OVERRIDE %}
            <!-- CSS specified by the user -->
            <link href="{{ SITEURL }}/{{ CSS_OVERRIDE }}" rel="stylesheet">
        {% endif %}

        <!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
        <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
        <!--[if lt IE 9]>
            <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
            <script src="https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js"></script>
        <![endif]-->
		
		<script src="{{ SITEURL }}/theme/js/jquery-3.3.1.min.js"></script>
    {% endblock head %}

	{% block opengraph %}
            {% for LOC in LOCALE %}
                <meta property="og:locale" content="{{ LOC }}">
            {% endfor %}
		<meta property="og:site_name" content="{{ SITENAME }}">
	{% endblock opengraph %}
	{% include 'analytics.html' %}
	</head>
	<body>
		<header id="header">
			<!-- Container -->
			<div class="container">
				<!-- Logo / Mobile Menu -->
				<div class="five columns">
				{% if LOGO %}
					<div id="logo">
						<a href="{{ SITEURL }}/"><img src="{{ SITEURL }}/images/{{ LOGO }}"></a>
					</div>
				{% else %}
					<div id="textlogo">
						<h1><a href="{{ SITEURL }}/">{{ SITENAME }}</a></h1>
					</div>
				{% endif %}
				</div>
						<!-- Navigation
				================================================== -->
				<div class="eleven columns">

					<nav id="navigation" class="menu">
						<ul id="responsive">

							<!--<li><a href="{{ SITEURL }}/">Home</a></li>-->

							{% for title, link in MENUITEMS %}
							    <li><a href="{{ link }}">{{ title }}</a></li>
							{% endfor %}

							{% if DISPLAY_PAGES_ON_MENU %}
							    {% for p in pages %}
							        <li{% if p == page %} class="active"{% endif %}><a href="{{ SITEURL }}/{{ p.url }}">{{ p.title }}</a></li>
							    {% endfor %}
							{% elif DISPLAY_CATEGORIES_ON_MENU %}
						        {% for cat, null in categories %}
						            <li{% if cat == category %} class="active"{% endif %}><a href="{{ SITEURL }}/{{ cat.url }}">{{ cat }}</a></li>
						        {% endfor %}
							{% endif %}
							<!--<li>-->
								<!--<div class="clearfix search-nav-clearfix"></div>-->
								<!--<form action="{{ SITEURL }}/search.html" onsubmit="return validateForm(this.elements['q'].value);">-->
								  <!--<input id="tipue_search_input" type="text" name="q" placeholder="Search">-->
								<!--</form>	-->
							<!--</li>-->
						</ul>
					</nav>
				</div>
			</div>
			
			<!-- Container / End -->
		</header>
		<!-- Header / End -->

		<!-- Breadcrumbs Container-->
		<div id="content-wrapper">
			<!--<section id="titlebar">-->
			<!---->
			<!--</section>-->

			<div class="container page-header-image">
				{% block image_header %}{% endblock image_header %}
			</div>

			<div class="container">
				{% block content_placeholder %}{% endblock content_placeholder %}
			</div>
			<!-- Container / End -->
		</div>
		<!-- Content Wrapper / End -->

		<div id="footer-bottom">
			<!-- Container -->
			<div class="container">
				<div class="six columns">&copy; 
					{{ COPYRIGHT }}
				</div>
				<div class="four columns">
					{% block pv %}
					{% endblock pv %}
				</div>
				{% if SOCIAL %}
					<div class="six columns">
						<ul class="social-icons-footer">
							{% for name,link in FA_SOCIAL %}
								<li class="social-icons-footer-fa-override">
									<a href="{{ link }}" class="tooltip top social-icons-footer-fa-override" title="{{ name }}">
										<i class="icon-{{ name|lower }}"></i>
									</a>
								</li>
						    {% endfor %}
						    {% for name,link in SOCIAL %}
								<li>
									<a href="{{ link }}" class="tooltip top" title="{{ name }}">
										<i class="icon-{{ name|lower }}"></i>
									</a>
								</li>
						    {% endfor %}
							<li><a href="{{ SITEURL }}/{{ FEED_ALL_ATOM }}" class="tooltip top" title="RSS"><i class="icon-rss"></i></a></li>
						</ul>
					</div>
				{% endif %}
			</div>
			<!-- Container / End -->
		</div>
		<!-- Footer Bottom / End -->

	<!-- Javascripts -->
	<script src="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/js/jquery-3.3.1.min.js"></script>
	{% include 'disqus_script.html' %}
	</body>
</html>
