{% extends "index.html" %}

{% block title %} - Tag {{ tag }}{% endblock title %}

{% block page_breadcrumbs %}
<li><a href="{{ SITEURL }}/tags.html">Tags</a></li>
<li>{{ tag }}</li>
{% endblock page_breadcrumbs %}
