{% extends "index.html" %}

{% block title %} - Articles by {{ author }}{% endblock title %}

{% block page_breadcrumbs %}
<li><a href="{{ SITEURL }}/authors.html">Authors</a></li>
<li>Articles by {{ author }}</li>
{% endblock page_breadcrumbs %}
