{% extends "index.html" %}

{% block title %} - Articles in {{ category }} category{% endblock title %}

{% block page_breadcrumbs %}
<li><a href="{{ SITEURL }}/categories.html">Categories</a></li>
<li>{{ category }}</li>
{% endblock page_breadcrumbs %}
