{% extends "base.html" %}

{% block content_placeholder %}
	<div class="sixteen columns">
		{% block content %}{% endblock content %}
	</div>
{% endblock content_placeholder %}


{% block pv %}
	<b>Page views: </b>
{% endblock pv %}