{% extends "with-sidebar.html" %}

{% block title %} - Tags{% endblock title %}

{% block page_breadcrumbs %}
<li>Tags</li>
{% endblock page_breadcrumbs %}

{% block content %}
    <h3 class="headline">Tags</h3>
    <span class="line" style="margin-bottom:30px;"></span>
    <div class="clearfix"></div>

    {%- for tag, articles in tags|sort %}
        <li><a href="{{ SITEURL }}/{{ tag.url }}">{{ tag }}</a> ({{ articles|count }})</li>
    {% endfor %}
{% endblock content %}
