{% if article.status != "draft" %}
<div class="sharing">
    {% if ADDTHIS_PUBID %}
        <!-- AddThis Button BEGIN -->
        <div class="addthis_toolbox addthis_default_style addthis_32x32_style">
            <a class="addthis_button_preferred_1"></a>
            <a class="addthis_button_preferred_2"></a>
            <a class="addthis_button_preferred_3"></a>
            <a class="addthis_button_preferred_4"></a>
            <a class="addthis_button_preferred_5"></a>
            <a class="addthis_button_preferred_6"></a>
            <a class="addthis_button_preferred_7"></a>
            <a class="addthis_button_preferred_8"></a>
            <a class="addthis_button_preferred_9"></a>
            <a class="addthis_button_compact"></a>
            <a class="addthis_counter addthis_bubble_style"></a>
        </div>
        <script type="text/javascript" src="https://s7.addthis.com/js/300/addthis_widget.js#pubid={{ ADDTHIS_PUBID }}"></script>
        <!-- AddThis Button END -->
    {% endif %}
</div>
<hr>
{% endif %}
