{% extends "with-sidebar.html" %}

{% block title %} - Authors{% endblock title %}

{% block page_breadcrumbs %}
<li>Authors</li>
{% endblock page_breadcrumbs %}

{% block content %}
    <h3 class="headline">Authors</h3>
    <span class="line" style="margin-bottom:30px;"></span>
    <div class="clearfix"></div>

    {% for author, articles in authors|sort %}
        <div class="post-preview">
            <a href="{{ SITEURL }}/{{ author.url }}" rel="bookmark">
                <p>
                    {{ author }} ({{ articles|count }})
                </p>
            </a>
        </div>
    {% endfor %}
{% endblock content %}
