{% extends "with-sidebar.html" %}

{% block title %} - Categories{% endblock title %}

{% block page_breadcrumbs %}
<li>Categories</li>
{% endblock page_breadcrumbs %}

{% block content %}
	<h3 class="headline">Categories</h3>
	<span class="line" style="margin-bottom:30px;"></span>
	<div class="clearfix"></div>
	
    <ul>
    {% for category, articles in categories %}
        <li><a href="{{ SITEURL }}/{{ category.url }}">{{ category }}</a></li>
    {% endfor %}
    </ul>
{% endblock content %}
